;;; rcd-org-agenda-dashboard.el --- RCD Org Agenda Dashboard  -*- lexical-binding: t; -*-

;; Copyright (C) 2022 by Jean Louis

;; Author: Jean Louis <bugs@gnu.support>
;; Version: 0.1
;; Package-Requires: (org rcd-dashboard)
;; Keywords: convenience extensions hypermedia outlines
;; URL: https://gnu.support/gnu-emacs/packages/GNU-Emacs-package-rcd-dashboard-el-Tool-to-build-Emacs-dashboards-76668.html

;; This file is not part of GNU Emacs.

;; This program is free software: you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation, either version 3 of the
;; License, or (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
;; General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program. If not, see <http://www.gnu.org/licenses/>.

;;; Commentary:
;;
;; Required packages are:
;; 
;; GNU Emacs package: rcd-utilities.el :
;; https://gnu.support/gnu-emacs/packages/rcd-utilities-el.html
;;
;; GNU Emacs package: rcd-org-agenda-dashboard.el -- RCD Org Agenda Dashboard:
;; https://gnu.support/gnu-emacs/packages/GNU-Emacs-package-rcd-dashboard-el-Tool-to-build-Emacs-dashboards-76668.html
;;
;; 1. Bind the function `rcd-org-agenda-dashboard' to any key
;; 
;; 2. Enjoy the non-blocking user-friendly mouse-compatible RCD Org Agenda Dashboard
;;

;;; Change Log:

;;; Code:

(require 'org)
(require 'rcd-dashboard)

(defun rcd-org-agenda-header ()
  "RCD Org Agenda Dashboard header."
  (rcd-dashboard-heading 
   (format "⭐ RCD Org Agenda ⭐ Dashboard ⭐%s"
	   (cond (user-full-name (format " for %s" user-full-name))
		 (t "")))))

(defun rcd-org-agenda-footer ()
  "RCD Org Agenda Dashboard footer."
  (rcd-dashboard-heading 
   "RCD Org Agenda Help\n")
  (rcd-button-insert "[q] to quit" #'rcd-dashboard-quit-window)
  (insert " or ")
  (rcd-button-insert "[mail suggestions]" 
		     (lambda (_)
		       (rcd-write-email 
			(or user-full-name user-login-name user-real-login-name (rcd-ask-get "Your name: "))
			(or user-mail-address (rcd-ask-get "Your e-maila address: "))
			"Jean Louis"
			"bugs@gnu.support" nil
			(rcd-ask-get "Suggest feature: "))))
  (insert " or [[mailto:bugs@gnu.support][Send e-mail]]\n\n"))

(defun rcd-org-agenda-functions ()
  "Ordinary Org Agenda functions for RCD Org Agenda."
  (rcd-dashboard-button "Agenda for current week or day" (lambda (_) (org-agenda-list)))
  (rcd-dashboard-button "List of all TODO entries" (lambda (_) (org-todo-list)))
  (rcd-dashboard-button "Match a TAGS/PROP/TODO query" (lambda (_) (org-tags-view)))
  (rcd-dashboard-button "Search for keywords" (lambda (_) (org-call-with-arg 'org-search-view '(4))))
  (rcd-dashboard-button "Search for keywords within TODO entries" (lambda (_)
								 (org-call-with-arg 'org-search-view '(4))))
  (rcd-dashboard-button "Export agenda views" (lambda (_) (call-interactively 'org-store-agenda-views)))
  (rcd-dashboard-button "Multi-occur" (lambda (_) (call-interactively #'org-occur-in-agenda-files)))
  (rcd-dashboard-button "Find :FLAGGED: entries" (lambda (_) (org-tags-view nil "+FLAGGED")))
  (insert "\n"))

;;;###autoload
(defun rcd-org-agenda-dashboard ()
  "RCD Org Agenda Dashboard."
  (interactive)
  (let ((rcd-dashboard-buffer-name "RCD Org Agenda Dashboard"))
    (rcd-dashboard 
     '(rcd-org-agenda-header
       rcd-org-agenda-functions
       rcd-org-agenda-footer
       read-only-mode)
     "rcd-org-agenda")))

(provide 'rcd-org-agenda-dashboard)

;;; rcd-org-agenda-dashboard.el ends here
